Modules
- japanese_
base_ form - This module defines various token filters and provides functionality to load them.
- japanese_
compound_ word - japanese_
kana - japanese_
katakana_ stem - japanese_
keep_ tags - japanese_
number - japanese_
reading_ form - japanese_
stop_ tags - keep_
words - korean_
keep_ tags - korean_
reading_ form - korean_
stop_ tags - length
- lowercase
- mapping
- remove_
diacritical_ mark - stop_
words - uppercase
Structs
- BoxToken
Filter - A
BoxTokenFilteris a wrapper around a boxed trait object that implements theTokenFiltertrait. This allows for dynamic dispatch of differentTokenFilterimplementations at runtime. TheBoxTokenFilterensures that the containedTokenFilteris thread-safe (SendandSync) and has a static lifetime. - Token
Filter Loader
Traits
- Token
Filter - A trait for token filters that can be applied to a vector of tokens.
- Token
Filter Clone - A trait for cloning token filters.